Index: source/ariba/Makefile.am
===================================================================
--- source/ariba/Makefile.am	(revision 4843)
+++ source/ariba/Makefile.am	(revision 4850)
@@ -335,5 +335,6 @@
   utility/bootstrap/modules/BootstrapModule.cpp \
   utility/bootstrap/modules/multicastdns/MulticastDns.cpp \
-  utility/bootstrap/modules/bluetoothsdp/BluetoothSdp.cpp
+  utility/bootstrap/modules/bluetoothsdp/BluetoothSdp.cpp \
+  utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.cpp
   
 nobase_libariba_la_HEADERS += \
@@ -342,5 +343,6 @@
   utility/bootstrap/modules/BootstrapModule.h \
   utility/bootstrap/modules/multicastdns/MulticastDns.h \
-  utility/bootstrap/modules/bluetoothsdp/BluetoothSdp.h
+  utility/bootstrap/modules/bluetoothsdp/BluetoothSdp.h \
+  utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.h
 
 #------------> utility :: configuration
Index: source/ariba/overlay/OverlayBootstrap.cpp
===================================================================
--- source/ariba/overlay/OverlayBootstrap.cpp	(revision 4843)
+++ source/ariba/overlay/OverlayBootstrap.cpp	(revision 4850)
@@ -89,6 +89,9 @@
 
 	// announcement for another spovnet
-	if( sid != spovnetid )
-		return;
+	if( sid != this->spovnetid ) return;
+
+	// announcement with our nodeid (either our announcement
+	// or a node with the same id, any way -> ignore)
+	if( nid == this->nodeid ) return;
 
 	// announcement for our spovnet
Index: source/ariba/utility/bootstrap/BootstrapManager.cpp
===================================================================
--- source/ariba/utility/bootstrap/BootstrapManager.cpp	(revision 4843)
+++ source/ariba/utility/bootstrap/BootstrapManager.cpp	(revision 4850)
@@ -40,4 +40,5 @@
 #include "BootstrapManager.h"
 #include "ariba/utility/bootstrap/modules/multicastdns/MulticastDns.h"
+#include "ariba/utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.h"
 
 namespace ariba {
@@ -65,7 +66,10 @@
 
 	switch(type){
-		case BootstrapTypeMulticastDns:
-			module = new MulticastDns(this);
-			break;
+	case BootstrapTypeMulticastDns:
+		module = new MulticastDns(this);
+		break;
+	case BootstrapTypePeriodicBroadcast:
+		module = new PeriodicBroadcast(this);
+		break;
 	}
 
@@ -113,4 +117,13 @@
 		RegistrationResult resone = RegistrationSucceeded;
 		resone = registerModule(BootstrapTypeMulticastDns);
+
+		if(resone != RegistrationSucceeded)
+			result = resone;
+	}
+
+	{ // periodic broadcast
+		RegistrationResult resone = RegistrationSucceeded;
+		resone = registerModule(BootstrapTypePeriodicBroadcast);
+
 		if(resone != RegistrationSucceeded)
 			result = resone;
@@ -126,4 +139,5 @@
 BootstrapManager::RegistrationResult BootstrapManager::unregisterAllModules(){
 	unregisterModule(BootstrapTypeMulticastDns);
+	unregisterModule(BootstrapTypePeriodicBroadcast);
 	/*  todo  ...  */
 
Index: source/ariba/utility/bootstrap/modules/multicastdns/MulticastDns.cpp
===================================================================
--- source/ariba/utility/bootstrap/modules/multicastdns/MulticastDns.cpp	(revision 4843)
+++ source/ariba/utility/bootstrap/modules/multicastdns/MulticastDns.cpp	(revision 4850)
@@ -85,6 +85,12 @@
 
 	// create a new avahi client
-	avahiclient = avahi_client_new( avahi_threaded_poll_get(avahipoll),
-			(AvahiClientFlags)0, MulticastDns::client_callback, this, &error );
+	avahiclient = avahi_client_new(
+			avahi_threaded_poll_get(avahipoll),
+			(AvahiClientFlags)0,
+			MulticastDns::client_callback,
+			this,
+			&error
+			);
+
 	if( avahiclient == NULL){
 		logging_error("creating avahi client failed with error "<<
Index: source/ariba/utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.cpp
===================================================================
--- source/ariba/utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.cpp	(revision 4850)
+++ source/ariba/utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.cpp	(revision 4850)
@@ -0,0 +1,124 @@
+// [License]
+// The Ariba-Underlay Copyright
+//
+// Copyright (c) 2008-2009, Institute of Telematics, UniversitÃ€t Karlsruhe (TH)
+//
+// Institute of Telematics
+// UniversitÃ€t Karlsruhe (TH)
+// Zirkel 2, 76128 Karlsruhe
+// Germany
+//
+// Redistribution and use in source and binary forms, with or without
+// modification, are permitted provided that the following conditions are
+// met:
+//
+// 1. Redistributions of source code must retain the above copyright
+// notice, this list of co// [License]
+// The Ariba-Underlay Copyright
+//
+// Copyright (c) 2008-2009, Institute of Telematics, UniversitÃ€t Karlsruhe (TH)
+//
+// Institute of Telematics
+// UniversitÃ€t Karlsruhe (TH)
+// Zirkel 2, 76128 Karlsruhe
+// Germany
+//
+// Redistribution and use in source and binary forms, with or without
+// modification, are permitted provided that the following conditions are
+// met:
+//
+// 1. Redistributions of source code must retain the above copyright
+// notice, this list of conditions and the following disclaimer.
+// 2. Redistributions in binary form must reproduce the above copyright
+// notice, this list of conditions and the following disclaimer in the
+// documentation and/or other materials provided with the distribution.
+//
+// THIS SOFTWARE IS PROVIDED BY THE INSTITUTE OF TELEMATICS ``AS IS'' AND
+// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE ARIBA PROJECT OR
+// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+//
+// The views and conclusions contained in the software and documentation
+// are those of the authors and should not be interpreted as representing
+// official policies, either expressed or implied, of the Institute of
+// Telematics.
+// [License]
+
+#include "PeriodicBroadcast.h"
+
+namespace ariba {
+namespace utility {
+
+use_logging_cpp(PeriodicBroadcast);
+const long PeriodicBroadcast::timerinterval = 1000;
+
+PeriodicBroadcast::PeriodicBroadcast(BootstrapInformationCallback* _callback) : BootstrapModule(_callback) {
+}
+
+PeriodicBroadcast::~PeriodicBroadcast(){
+}
+
+string PeriodicBroadcast::getName(){
+	return "PeriodicBroadcast";
+}
+
+string PeriodicBroadcast::getInformation(){
+	return "periodic broadcasting of service information";
+}
+
+bool PeriodicBroadcast::isFunctional(){
+	return true;
+}
+
+void PeriodicBroadcast::start(){
+	Timer::setInterval( timerinterval );
+	Timer::start();
+}
+
+void PeriodicBroadcast::stop(){
+	Timer::stop();
+
+	boost::mutex::scoped_lock lock( localServicesMutex );
+	localServices.clear();
+}
+
+void PeriodicBroadcast::publishService(string name, string info1, string info2, string info3){
+	Service service;
+
+	service.name = name;
+	service.info1 = info1;
+	service.info2 = info2;
+	service.info3 = info3;
+
+	boost::mutex::scoped_lock lock( localServicesMutex );
+	localServices.insert( std::make_pair(name, service) );
+}
+
+void PeriodicBroadcast::revokeService(string name){
+	boost::mutex::scoped_lock lock( localServicesMutex );
+
+	ServiceList::iterator i = localServices.find( name );
+	if( i != localServices.end() ) localServices.erase( name );
+}
+
+void PeriodicBroadcast::eventFunction(){
+	sendLocalServices();
+	updateRemoteServices();
+}
+
+void PeriodicBroadcast::sendLocalServices(){
+
+}
+
+void PeriodicBroadcast::updateRemoteServices(){
+
+}
+
+}} //namespace ariba, utility
Index: source/ariba/utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.h
===================================================================
--- source/ariba/utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.h	(revision 4850)
+++ source/ariba/utility/bootstrap/modules/periodicbroadcast/PeriodicBroadcast.h	(revision 4850)
@@ -0,0 +1,98 @@
+// [License]
+// The Ariba-Underlay Copyright
+//
+// Copyright (c) 2008-2009, Institute of Telematics, UniversitÃ€t Karlsruhe (TH)
+//
+// Institute of Telematics
+// UniversitÃ€t Karlsruhe (TH)
+// Zirkel 2, 76128 Karlsruhe
+// Germany
+//
+// Redistribution and use in source and binary forms, with or without
+// modification, are permitted provided that the following conditions are
+// met:
+//
+// 1. Redistributions of source code must retain the above copyright
+// notice, this list of conditions and the following disclaimer.
+// 2. Redistributions in binary form must reproduce the above copyright
+// notice, this list of conditions and the following disclaimer in the
+// documentation and/or other materials provided with the distribution.
+//
+// THIS SOFTWARE IS PROVIDED BY THE INSTITUTE OF TELEMATICS ``AS IS'' AND
+// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE ARIBA PROJECT OR
+// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
+// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+//
+// The views and conclusions contained in the software and documentation
+// are those of the authors and should not be interpreted as representing
+// official policies, either expressed or implied, of the Institute of
+// Telematics.
+// [License]
+
+#ifndef __PERIODIC_BROADCAST_H
+#define __PERIODIC_BROADCAST_H
+
+#include "ariba/config.h"
+
+#include <iostream>
+#include <string>
+#include <map>
+#include <boost/thread/mutex.hpp>
+#include <boost/thread/thread.hpp>
+#include "ariba/utility/bootstrap/modules/BootstrapModule.h"
+#include "ariba/utility/logging/Logging.h"
+#include "ariba/utility/system/Timer.h"
+
+using std::map;
+using std::string;
+
+namespace ariba {
+namespace utility {
+
+class PeriodicBroadcast : public BootstrapModule, public Timer {
+	use_logging_h(PeriodicBroadcast);
+public:
+	PeriodicBroadcast(BootstrapInformationCallback* _callback);
+	virtual ~PeriodicBroadcast();
+
+	virtual void start();
+	virtual void stop();
+
+	virtual string getName();
+	virtual string getInformation();
+	virtual bool isFunctional();
+	virtual void publishService(string name, string info1, string info2, string info3);
+	virtual void revokeService(string name);
+
+protected:
+	virtual void eventFunction();
+
+private:
+	void sendLocalServices();
+	void updateRemoteServices();
+
+	static const long timerinterval;
+
+	typedef struct _Service {
+		string name;
+		string info1;
+		string info2;
+		string info3;
+	} Service;
+
+	typedef map<string,Service> ServiceList;
+	ServiceList localServices;
+	boost::mutex localServicesMutex;
+
+};
+
+}} //namespace ariba, utility
+
+#endif // __BLUETOOTH_SDP_H

Index: source/ariba/utility/bootstrap/BootstrapManager.h
===================================================================
--- source/ariba/utility/bootstrap/BootstrapManager.h	(revision 4843)
+++ source/ariba/utility/bootstrap/BootstrapManager.h	(revision 4850)
@@ -73,5 +73,6 @@
 
 	enum BootstrapType {
-		BootstrapTypeMulticastDns,	// use mDNS bootstrapping
+		BootstrapTypeMulticastDns,			// use mDNS bootstrapping
+		BootstrapTypePeriodicBroadcast, 	// stupid periodic broadcasting
 	};
 